@@ -4,14 +4,16 @@ from .base import BaseDocumentArray
 from .mixins import AllMixins
 
 if TYPE_CHECKING:
-    from ..types import DocumentArraySourceType
+    from ..typing import DocumentArraySourceType
     from .memory import DocumentArrayInMemory
     from .sqlite import DocumentArraySqlite
     from .annlite import DocumentArrayAnnlite
     from .weaviate import DocumentArrayWeaviate
+    from .elastic import DocumentArrayElastic
     from .storage.sqlite import SqliteConfig
     from .storage.annlite import AnnliteConfig
     from .storage.weaviate import WeaviateConfig
+    from .storage.elastic import ElasticConfig
 
 
 class DocumentArray(AllMixins, BaseDocumentArray):
@@ -52,6 +54,26 @@ class DocumentArray(AllMixins, BaseDocumentArray):
         """Create a AnnLite-powered DocumentArray object."""
         ...
 
+    @overload
+    def __new__(
+        cls,
+        _docs: Optional['DocumentArraySourceType'] = None,
+        storage: str = 'elasticsearch',
+        config: Optional[Union['ElasticConfig', Dict]] = None,
+    ) -> 'DocumentArrayElastic':
+        """Create a Elastic-powered DocumentArray object."""
+        ...
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args, **kwargs):
+        """
+        Ensures that offset2ids are stored in the db after
+        operations in the DocumentArray are performed.
+        """
+        self._save_offset2ids()
+
     def __new__(cls, *args, storage: str = 'memory', **kwargs):
         if cls is DocumentArray:
             if storage == 'memory':
@@ -74,6 +96,11 @@ class DocumentArray(AllMixins, BaseDocumentArray):
                 from .qdrant import DocumentArrayQdrant
 
                 instance = super().__new__(DocumentArrayQdrant)
+            elif storage == 'elasticsearch':
+                from .elastic import DocumentArrayElastic
+
+                instance = super().__new__(DocumentArrayElastic)
+
             else:
                 raise ValueError(f'storage=`{storage}` is not supported.')
         else:
