@@ -13,6 +13,7 @@ class PostMixin:
         show_progress: bool = False,
         batch_size: Optional[int] = None,
         parameters: Optional[Dict] = None,
+        **kwargs,
     ) -> 'DocumentArray':
         """Posting itself to a remote Flow/Sandbox and get the modified DocumentArray back
 
@@ -49,7 +50,7 @@ class PostMixin:
         _tls = False
 
         if _scheme in ('grpcs', 'https', 'wss'):
-            _scheme = _scheme[:-2]
+            _scheme = _scheme[:-1]
             _tls = True
 
         if _scheme == 'ws':
@@ -66,20 +67,22 @@ class PostMixin:
                     show_progress=show_progress,
                     request_size=batch_size,
                     parameters=parameters,
+                    **kwargs,
                 )
         elif _scheme in ('grpc', 'http', 'ws', 'websocket'):
-            if _port is None:
-                raise ValueError(f'can not determine port from {host}')
-
             from jina import Client
 
-            c = Client(host=r.hostname, port=_port, protocol=_scheme, https=_tls)
+            if _port:
+                standardized_host += f':{_port}'
+
+            c = Client(host=standardized_host)
             return c.post(
                 _on,
                 inputs=self,
                 show_progress=show_progress,
                 request_size=batch_size,
                 parameters=parameters,
+                **kwargs,
             )
         else:
             raise ValueError(f'unsupported scheme: {r.scheme}')
