@@ -9,16 +9,17 @@ from typing import (
     List,
     Iterable,
     Any,
+    Tuple,
     Mapping,
 )
 
 import numpy as np
 from elasticsearch import Elasticsearch
-from elasticsearch.helpers import bulk
+from elasticsearch.helpers import parallel_bulk
 
-from ..base.backend import BaseBackendMixin
+from ..base.backend import BaseBackendMixin, TypeMap
 from .... import Document
-from ....helper import dataclass_from_dict
+from ....helper import dataclass_from_dict, _safe_cast_int
 
 if TYPE_CHECKING:
     from ....typing import (
@@ -41,11 +42,21 @@ class ElasticConfig:
     batch_size: int = 64
     ef_construction: Optional[int] = None
     m: Optional[int] = None
+    columns: Optional[List[Tuple[str, str]]] = None
 
 
 class BackendMixin(BaseBackendMixin):
     """Provide necessary functions to enable this storage backend."""
 
+    TYPE_MAP = {
+        'str': TypeMap(type='text', converter=str),
+        'float': TypeMap(type='float', converter=float),
+        'int': TypeMap(type='integer', converter=_safe_cast_int),
+        'double': TypeMap(type='double', converter=float),
+        'long': TypeMap(type='long', converter=_safe_cast_int),
+        'bool': TypeMap(type='boolean', converter=bool),
+    }
+
     def _init_storage(
         self,
         _docs: Optional['DocumentArraySourceType'] = None,
@@ -68,6 +79,9 @@ class BackendMixin(BaseBackendMixin):
 
         self._index_name_offset2id = 'offset2id__' + config.index_name
         self._config = config
+
+        self._config.columns = self._normalize_columns(self._config.columns)
+
         self.n_dim = self._config.n_dim
         self._client = self._build_client()
         self._build_offset2id_index()
@@ -110,6 +124,12 @@ class BackendMixin(BaseBackendMixin):
                     'index': True,
                 }
 
+        for col, coltype in self._config.columns:
+            da_schema['mappings']['properties'][col] = {
+                'type': self._map_type(coltype),
+                'index': True,
+            }
+
         if self._config.m or self._config.ef_construction:
             index_options = {
                 'type': 'hnsw',
@@ -139,7 +159,12 @@ class BackendMixin(BaseBackendMixin):
         return client
 
     def _send_requests(self, request):
-        bulk(self._client, request)
+        failed_index = []
+        for success, info in parallel_bulk(self._client, request, raise_on_error=False):
+            if not success:
+                failed_index.append(info['index'])
+
+        return failed_index
 
     def _refresh(self, index_name):
         self._client.indices.refresh(index=index_name)
@@ -159,9 +184,25 @@ class BackendMixin(BaseBackendMixin):
                 }  # id here
                 for offset_, id_ in enumerate(self._offset2ids.ids)
             ]
-            r = bulk(self._client, requests)
+            self._send_requests(requests)
             self._client.indices.refresh(index=self._index_name_offset2id)
 
+            # Clean trailing unused offsets
+            offset_count = self._client.count(index=self._index_name_offset2id)
+            unused_offsets = range(len(self._offset2ids.ids), offset_count['count'])
+
+            if len(unused_offsets) > 0:
+                requests = [
+                    {
+                        '_op_type': 'delete',
+                        '_id': offset_,  # note offset goes here because it's what we want to get by
+                        '_index': self._index_name_offset2id,
+                    }
+                    for offset_ in unused_offsets
+                ]
+                self._send_requests(requests)
+                self._client.indices.refresh(index=self._index_name_offset2id)
+
     def _get_offset2ids_meta(self) -> List:
         """Return the offset2ids stored in elastic
 
