@@ -94,8 +94,7 @@ class BackendMixin(BaseBackendMixin):
         )
         self._config = config
 
-        if self._config.columns is None:
-            self._config.columns = []
+        self._config.columns = self._normalize_columns(self._config.columns)
 
         self._schemas = self._load_or_create_weaviate_schema()
 
