@@ -6,7 +6,7 @@ import numpy as np
 
 if TYPE_CHECKING:
     from pydantic import BaseModel
-    from ...types import T
+    from ...typing import T
     from ..pydantic_model import PydanticDocument
 
 
@@ -33,6 +33,8 @@ class PydanticMixin:
                 _p_dict[f] = v.to_pydantic_model()
             elif f in ('scores', 'evaluations'):
                 _p_dict[f] = {k: v.to_dict() for k, v in v.items()}
+            elif f == 'blob':
+                _p_dict[f] = base64.b64encode(v).decode('utf8')
             else:
                 _p_dict[f] = v
         return DP(**_p_dict)
@@ -66,13 +68,7 @@ class PydanticMixin:
             elif f_name == 'embedding' or f_name == 'tensor':
                 fields[f_name] = np.array(value)
             elif f_name == 'blob':
-                # here is a dirty fishy itchy trick
-                # the original bytes will be encoded two times:
-                # first time is real during `to_dict/to_json`, it converts into base64 string
-                # second time is at `from_dict/from_json`, it is unnecessary yet inevitable, the result string get
-                # converted into a binary string and encoded again.
-                # consequently, we need to decode two times here!
-                fields[f_name] = base64.b64decode(base64.b64decode(value))
+                fields[f_name] = base64.b64decode(value)
             else:
                 fields[f_name] = value
 
